@@ -8,8 +8,8 @@ import type {
     IHistogram,
     ValueCount,
     Interval,
-    TimeBin,
-    IStringMeta
+    IStringMeta,
+    ITemporalMeta,
 } from '../../common/exchangeInterfaces';
 import _ from 'lodash';
 
@@ -159,7 +159,6 @@ export class PythonPandasExecutor {
                     // TODO update this to async so more reactive https://zellwk.com/blog/async-await-in-loops/
                     const dfColMap: IDFColMap = {};
                     const python_ids = await this.getObjectIds(vars_DF);
-
                     for (let index = 0; index < vars_DF.length; index++) {
                         const dfName = vars_DF[index];
                         let { columnsWithTypes, duplicates } = await this.getColumns(dfName);
@@ -251,7 +250,6 @@ export class PythonPandasExecutor {
             const res = await this.executePythonAP(code);
             const content = res['content']; // might be null
             const json_res = JSON.parse(content?.join(""));
-
             const columnsWithTypes: IColTypeTuple[] = []
 
             let uniqueNames = new Set<string>()
@@ -260,7 +258,8 @@ export class PythonPandasExecutor {
             for (const item of json_res) {
                 columnsWithTypes.push({
                     col_name: item["colName"],
-                    col_type: item["type"]
+                    col_type: item["type"],
+                    col_is_index: item["isIndex"],
                 })
                 if (uniqueNames.has(item["colName"])) {
                     duplicatedNames.add(item["colName"])
@@ -295,42 +294,13 @@ export class PythonPandasExecutor {
         }
     }
 
-    public async getQuantMeta(
-        dfName: string,
-        colName: string
-    ): Promise<IQuantMeta> {
-        const code = `digautoprofiler.getQuantMeta(${dfName}, "${replaceSpecial(colName)}")`
-        try {
-            const res = await this.executePythonAP(code);
-            const content = res['content']; // might be null
-            const json_res = JSON.parse(content?.join("").replace(/'/g, '')); // remove single quotes bc not JSON parseable
-
-            return {
-                min: parseFloat(json_res['min']),
-                q25: parseFloat(json_res['25%']),
-                q50: parseFloat(json_res['50%']),
-                q75: parseFloat(json_res['75%']),
-                max: parseFloat(json_res['max']),
-                mean: parseFloat(json_res['mean'])
-            };
-        } catch (error) {
-            console.warn(`[Error caught] in getQuantMeta executing: ${code} `, error);
-            return {
-                min: undefined,
-                q25: undefined,
-                q50: undefined,
-                q75: undefined,
-                max: undefined,
-                mean: undefined
-            };
-        }
-    }
-
     public async getColMeta(
         dfName: string,
-        colName: string
+        colName: string,
+        isIndex: boolean,
     ): Promise<IColMeta> {
-        const code = `digautoprofiler.getColMeta(${dfName}, "${replaceSpecial(colName)}")`;
+        const isIndexPy = isIndex ? "True" : "False";
+        const code = `digautoprofiler.getColMeta(${dfName}, "${replaceSpecial(colName)}", ${isIndexPy})`;
         try {
             const res = await this.executePythonAP(code);
             const content = res['content'];
@@ -347,11 +317,60 @@ export class PythonPandasExecutor {
         }
     }
 
-    public async getStringStats(
+    public async getQuantMeta(
         dfName: string,
-        colName: string
+        colName: string,
+        isIndex: boolean,
+    ): Promise<IQuantMeta> {
+        const isIndexPy = isIndex ? "True" : "False";
+        const code = `digautoprofiler.getQuantMeta(${dfName}, "${replaceSpecial(colName)}", ${isIndexPy})`
+        try {
+            const res = await this.executePythonAP(code);
+            const content = res['content']; // might be null
+            const json_res = JSON.parse(content[0].replace(/'/g, '')); // remove single quotes bc not JSON parseable
+
+            return {
+                min: parseFloat(json_res['min']),
+                q25: parseFloat(json_res['25%']),
+                q50: parseFloat(json_res['50%']),
+                q75: parseFloat(json_res['75%']),
+                max: parseFloat(json_res['max']),
+                mean: parseFloat(json_res['mean']),
+
+                sd_outlier: parseInt(content[1]),
+                iqr_outlier: parseInt(content[2]),
+                sortedness: content[3],
+                n_zero: parseInt(content[4]),
+                n_negative: parseInt(content[5]),
+                n_positive: parseInt(content[6]),
+            };
+        } catch (error) {
+            console.warn(`[Error caught] in getQuantMeta executing: ${code} `, error);
+            return {
+                min: undefined,
+                q25: undefined,
+                q50: undefined,
+                q75: undefined,
+                max: undefined,
+                mean: undefined,
+                sd_outlier: undefined,
+                iqr_outlier: undefined,
+                sortedness: undefined,
+                n_zero: undefined,
+                n_positive: undefined,
+                n_negative: undefined,
+            };
+        }
+    }
+
+    public async getStringMeta(
+        dfName: string,
+        colName: string,
+        isIndex: boolean,
     ): Promise<IStringMeta> {
-        const code = `digautoprofiler.getStringStats(${dfName}, "${replaceSpecial(colName)}")`;
+        const isIndexPy = isIndex ? "True" : "False";
+        const code = `digautoprofiler.getStringMeta(${dfName}, "${replaceSpecial(colName)}", ${isIndexPy})`;
+
         try {
             const res = await this.executePythonAP(code);
             const content = res['content'];
@@ -370,17 +389,40 @@ export class PythonPandasExecutor {
         }
     }
 
+    public async getTemporalMeta(
+        dfName: string,
+        colName: string,
+        isIndex: boolean,
+    ): Promise<ITemporalMeta> {
+        const isIndexPy = isIndex ? "True" : "False";
+        const code = `digautoprofiler.getTemporalMeta(${dfName}, "${replaceSpecial(colName)}", ${isIndexPy})`;
+        try {
+            const res = await this.executePythonAP(code);
+            const content = res['content'];
+            return {
+                sortedness: content[0],
+            }
+        } catch (error) {
+            console.warn(`[Error caught] in getTemporalFacts executing: ${code}`, error);
+            return {
+                sortedness: undefined
+            }
+        }
+    }
+
     public async getValueCounts(
         dfName: string,
         colName: string,
+        isIndex: boolean,
         n = 10
     ): Promise<ValueCount[]> {
-        const code = `digautoprofiler.getValueCounts(${dfName}, "${replaceSpecial(colName)}", ${n})`;
+        const isIndexPy = isIndex ? "True" : "False";
+        const code = `digautoprofiler.getValueCounts(${dfName}, "${replaceSpecial(colName)}", ${n}, ${isIndexPy})`;
         try {
             const res = await this.executePythonAP(code);
             const data: ValueCount[] = [];
             const content = res['content']; // might be null
-            const json_res = JSON.parse(content?.join("").replace(/'/g, '')); // remove single quotes bc not JSON parseable
+            const json_res = JSON.parse(content?.join("").replace(/'/g, '\'')); // remove single quotes bc not JSON parseable
             Object.keys(json_res).forEach(k => {
                 data.push({ value: k, count: json_res[k] });
             });
@@ -394,9 +436,11 @@ export class PythonPandasExecutor {
     public async getQuantBinnedData(
         dfName: string,
         colName: string,
+        isIndex: boolean,
         maxbins = 20
     ): Promise<IHistogram> {
-        const code = `digautoprofiler.getQuantBinnedData(${dfName}, "${replaceSpecial(colName)}", ${maxbins})`
+        const isIndexPy = isIndex ? "True" : "False";
+        const code = `digautoprofiler.getQuantBinnedData(${dfName}, "${replaceSpecial(colName)}", ${maxbins}, ${isIndexPy})`
         try {
             const res = await this.executePythonAP(code);
             const content = res['content'];
@@ -424,13 +468,14 @@ export class PythonPandasExecutor {
     public async getTempBinnedData(
         dfName: string,
         colName: string,
+        isIndex: boolean,
         maxbins = 200
-    ): Promise<{ timebin: TimeBin[], histogram: IHistogram }> {
-        const code = `digautoprofiler.getTempBinnedData(${dfName}, "${replaceSpecial(colName)}", ${maxbins})`;
+    ): Promise<IHistogram> {
+        const isIndexPy = isIndex ? "True" : "False";
+        const code = `digautoprofiler.getTempBinnedData(${dfName}, "${replaceSpecial(colName)}", ${maxbins}, ${isIndexPy})`;
         try {
             const res = await this.executePythonAP(code);
             const content = res['content'];
-            const timebinData: TimeBin[] = [];
             const histogram: IHistogram = []
             const json_res = JSON.parse(content[0].replace(/'/g, '')); // remove single quotes bc not JSON parseable
             const true_minimum = parseFloat(content[1]);
@@ -442,17 +487,6 @@ export class PythonPandasExecutor {
                 const lowNum = parseFloat(low)
                 const highNum = parseFloat(high)
 
-                const lowDate = new Date(lowNum * 1000)
-                const highDate = new Date(highNum * 1000)
-
-                // for time detail chart
-                timebinData.push({
-                    // Pandas extends the minimum bin an arbitrary number below the col's minimum so we shift the lowest bin boundary to the actual minimum
-                    ts_start: i === 0 ? new Date(true_minimum * 1000) : lowDate,
-                    ts_end: highDate,
-                    count: json_res[k],
-                });
-
                 // for histogram preview
                 histogram.push(
                     {
@@ -463,10 +497,10 @@ export class PythonPandasExecutor {
                     }
                 )
             });
-            return { timebin: timebinData, histogram: histogram };
+            return histogram;
         } catch (error) {
             console.warn(`[Error caught] in getTempBinnedData executing: ${code}`, error);
-            return { timebin: [], histogram: [] };
+            return [];
         }
     }
 
@@ -479,9 +513,11 @@ export class PythonPandasExecutor {
      */
     public async getTempInterval(
         dfName: string,
-        colName: string
+        colName: string,
+        isIndex: boolean
     ): Promise<Interval> {
-        const code = `digautoprofiler.getTempInterval(${dfName}, "${replaceSpecial(colName)}")`;
+        const isIndexPy = isIndex ? "True" : "False";
+        const code = `digautoprofiler.getTempInterval(${dfName}, "${replaceSpecial(colName)}"), ${isIndexPy}`;
         try {
             const res = await this.executePythonAP(code);
             const content = res['content'];
